## 0.4.0

fix: do not run model if editor was closed without writing #7 0.4.0.dev2
feat: add support for Edit mode #12 0.4.0.dev2
feat: add support to jinja template all string type parameters #13 0.4.0.dev2
feat: add --verbose flag #8 0.4.0.dev3
feat: create history api, and save history #17 0.4.0.dev4
fix: do not block for missing stdin #18 0.4.0.dev11
feat: editor now opens full toml #20 0.4.0.dev12
